[![Build Status](https://dev.azure.com/apeer-micro/apeer-open-source/_apis/build/status/apeer-micro.apeer-ometiff-library?branchName=master)](https://dev.azure.com/apeer-micro/apeer-open-source/_build/latest?definitionId=2&branchName=master)

-----

# apeer-ometiff-library

Easily read and write ome-tiff images in python

The omexmlClass.py file in this library is taken from python-bioformats. We included this part in this library, because it allows us to use these functions without needing to have a Java-VM in Apeer docker files.
